/* clock.c generated by valac 0.18.0.77-c8a68, the Vala compiler
 * generated from clock.vala, do not modify */

/*
 * Copyright (C) 2013  Paolo Borelli <pborelli@gnome.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>


#define CLOCKS_TYPE_CLOCK (clocks_clock_get_type ())
#define CLOCKS_CLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_CLOCK, ClocksClock))
#define CLOCKS_IS_CLOCK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_CLOCK))
#define CLOCKS_CLOCK_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), CLOCKS_TYPE_CLOCK, ClocksClockIface))

typedef struct _ClocksClock ClocksClock;
typedef struct _ClocksClockIface ClocksClockIface;

#define CLOCKS_TYPE_TOOLBAR (clocks_toolbar_get_type ())
#define CLOCKS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_TOOLBAR, ClocksToolbar))
#define CLOCKS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_TOOLBAR, ClocksToolbarClass))
#define CLOCKS_IS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_TOOLBAR))
#define CLOCKS_IS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_TOOLBAR))
#define CLOCKS_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_TOOLBAR, ClocksToolbarClass))

typedef struct _ClocksToolbar ClocksToolbar;
typedef struct _ClocksToolbarClass ClocksToolbarClass;

struct _ClocksClockIface {
	GTypeInterface parent_iface;
	void (*activate_new) (ClocksClock* self);
	void (*activate_select_all) (ClocksClock* self);
	void (*activate_select_none) (ClocksClock* self);
	void (*update_toolbar) (ClocksClock* self);
	const gchar* (*get_label) (ClocksClock* self);
	void (*set_label) (ClocksClock* self, const gchar* value);
	ClocksToolbar* (*get_toolbar) (ClocksClock* self);
	void (*set_toolbar) (ClocksClock* self, ClocksToolbar* value);
};



GType clocks_toolbar_get_type (void) G_GNUC_CONST;
GType clocks_clock_get_type (void) G_GNUC_CONST;
void clocks_clock_activate_new (ClocksClock* self);
static void clocks_clock_real_activate_new (ClocksClock* self);
void clocks_clock_activate_select_all (ClocksClock* self);
static void clocks_clock_real_activate_select_all (ClocksClock* self);
void clocks_clock_activate_select_none (ClocksClock* self);
static void clocks_clock_real_activate_select_none (ClocksClock* self);
void clocks_clock_update_toolbar (ClocksClock* self);
static void clocks_clock_real_update_toolbar (ClocksClock* self);
const gchar* clocks_clock_get_label (ClocksClock* self);
void clocks_clock_set_label (ClocksClock* self, const gchar* value);
ClocksToolbar* clocks_clock_get_toolbar (ClocksClock* self);
void clocks_clock_set_toolbar (ClocksClock* self, ClocksToolbar* value);


static void clocks_clock_real_activate_new (ClocksClock* self) {
}


void clocks_clock_activate_new (ClocksClock* self) {
	g_return_if_fail (self != NULL);
	CLOCKS_CLOCK_GET_INTERFACE (self)->activate_new (self);
}


static void clocks_clock_real_activate_select_all (ClocksClock* self) {
}


void clocks_clock_activate_select_all (ClocksClock* self) {
	g_return_if_fail (self != NULL);
	CLOCKS_CLOCK_GET_INTERFACE (self)->activate_select_all (self);
}


static void clocks_clock_real_activate_select_none (ClocksClock* self) {
}


void clocks_clock_activate_select_none (ClocksClock* self) {
	g_return_if_fail (self != NULL);
	CLOCKS_CLOCK_GET_INTERFACE (self)->activate_select_none (self);
}


static void clocks_clock_real_update_toolbar (ClocksClock* self) {
}


void clocks_clock_update_toolbar (ClocksClock* self) {
	g_return_if_fail (self != NULL);
	CLOCKS_CLOCK_GET_INTERFACE (self)->update_toolbar (self);
}


const gchar* clocks_clock_get_label (ClocksClock* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return CLOCKS_CLOCK_GET_INTERFACE (self)->get_label (self);
}


void clocks_clock_set_label (ClocksClock* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	CLOCKS_CLOCK_GET_INTERFACE (self)->set_label (self, value);
}


ClocksToolbar* clocks_clock_get_toolbar (ClocksClock* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return CLOCKS_CLOCK_GET_INTERFACE (self)->get_toolbar (self);
}


void clocks_clock_set_toolbar (ClocksClock* self, ClocksToolbar* value) {
	g_return_if_fail (self != NULL);
	CLOCKS_CLOCK_GET_INTERFACE (self)->set_toolbar (self, value);
}


static void clocks_clock_base_init (ClocksClockIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_string ("label", "label", "label", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
		g_object_interface_install_property (iface, g_param_spec_object ("toolbar", "toolbar", "toolbar", CLOCKS_TYPE_TOOLBAR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
		iface->activate_new = clocks_clock_real_activate_new;
		iface->activate_select_all = clocks_clock_real_activate_select_all;
		iface->activate_select_none = clocks_clock_real_activate_select_none;
		iface->update_toolbar = clocks_clock_real_update_toolbar;
	}
}


GType clocks_clock_get_type (void) {
	static volatile gsize clocks_clock_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_clock_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksClockIface), (GBaseInitFunc) clocks_clock_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType clocks_clock_type_id;
		clocks_clock_type_id = g_type_register_static (G_TYPE_INTERFACE, "ClocksClock", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (clocks_clock_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&clocks_clock_type_id__volatile, clocks_clock_type_id);
	}
	return clocks_clock_type_id__volatile;
}



