@define-color clocks_go_color_a #7fc141;
@define-color clocks_go_color_b #8fc95d;
@define-color clocks_stop_color_a #f44848;
@define-color clocks_stop_color_b #ff6565;

.clocks-content-view {
    border-style: solid;
    border-color: @borders;
    border-width: 1px 0 0 0;
    border-radius: 0;
}

.clocks-digital-renderer {
    background-color: transparent;
}

.clocks-digital-renderer.stripe {
    font-size: 32px;
}

/* world */

.clocks-digital-renderer.light.stripe {
    background-color: rgba(255, 255, 255, 0.4);
    color: black;
}

.clocks-digital-renderer.light.stripe:prelight {
    background-color: rgba(255, 255, 255, 0.6);
}

.clocks-digital-renderer.dark.stripe {
    background-color: rgba(0, 0, 0, 0.4);
    color: white;
}

.clocks-digital-renderer.dark.stripe:prelight {
    background-color: rgba(0, 0, 0, 0.2);
}

/* alarms */

.clocks-digital-renderer.active {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@theme_selected_bg_color,1.2)), to(@theme_selected_bg_color));
    color: white;
}

.clocks-digital-renderer.active:prelight {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@theme_selected_bg_color, 1.4)), to(@theme_selected_bg_color));
    text-shadow: 0 2px 2px rgba(0,0,0,0.5)
}

.clocks-digital-renderer.snoozing {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(@warning_bg_color), to(shade(@warning_bg_color,0.9)));
    color: white;
}

.clocks-digital-renderer.snoozing:prelight {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@warning_bg_color,1.1)), to(shade(@warning_bg_color,0.99)));
    text-shadow: 0 2px 2px rgba(0,0,0,0.5)
}

.clocks-digital-renderer.inactive {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@insensitive_bg_color,0.9)), to(shade(@insensitive_bg_color,0.85)));
    color: shade(@insensitive_fg_color,0.9);
}

.clocks-digital-renderer.inactive:prelight {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@insensitive_bg_color,0.99)), to(shade(@insensitive_bg_color,0.9)));
    color: @insensitive_fg_color;
}

.clocks-digital-renderer.active.stripe,
.clocks-digital-renderer.snoozing.stripe,
.clocks-digital-renderer.inactive.stripe {
    background-color: transparent;
    background-image: none;
}

.clocks-time-label {
    font-size: 64px;
}

.clocks-secondary-time-label {
    font-size: 18px;
}

.clocks-button {
    font-size: 18px;
}

.clocks-alarm-setup-spinbutton {
    font-size: 32px;
}

.clocks-spinbutton {
    font-size: 64px;
}

.clocks-go {
    background-image: linear-gradient(to bottom,
                                      @clocks_go_color_a,
                                      darker(@clocks_go_color_a) 70%
                                      );
    color: #ffffff;
    border-image: url("button-border-go.svg") 3 3 4 3 / 3 3 4 3 stretch;
    border-radius: 3px;
    border-width: 1px 1px 2px 1px;
    border-style: solid;
    border-color: transparent;
}

.clocks-go:hover {
    background-image: linear-gradient(to bottom,
                                      @clocks_go_color_b,
                                      darker(@clocks_go_color_b) 70%
                                      );
}

.clocks-go:active {
    background-image: linear-gradient(to bottom,
                                      darker(@clocks_go_color_a),
                                      @clocks_go_color_a
                                      );
    border-image: url("button-border-go-active.svg") 3 3 4 3 / 3 3 4 3 stretch;
}

.clocks-stop {
    background-image: linear-gradient(to bottom,
                                      @clocks_stop_color_a,
                                      darker(@clocks_stop_color_a) 70%
                                      );
    color: #ffffff;
    border-image: url("button-border-stop.svg") 3 3 4 3 / 3 3 4 3 stretch;
    border-radius: 3px;
    border-width: 1px 1px 2px 1px;
    border-style: solid;
    border-color: transparent;
}

.clocks-stop:hover {
    background-image: linear-gradient(to bottom,
                                      @clocks_stop_color_b,
                                      darker(@clocks_stop_color_b) 70%
                                      );
}

.clocks-stop:active {
    background-image: linear-gradient(to bottom,
                                      darker(@clocks_stop_color_a),
                                      @clocks_stop_color_a
                                      );
    border-image: url("button-border-stop-active.svg") 3 3 4 3 / 3 3 4 3 stretch;
}

.view.clocks-laps {
    font-size: larger;
    background-color: @theme_bg_color;
    color: @theme_fg_color;
}

.frame.clocks-laps-scroll {
    border-style: solid;
    border-color: @borders;
    border-width: 1px 0 0 0;
    border-radius: 0;
}

.clocks-laps column-header.button,
.clocks-laps column-header .button,
.clocks-laps column-header.button:insensitive,
.clocks-laps column-header .button:insensitive,
.clocks-laps column-header.button:hover,
.clocks-laps column-header .button:hover,
.clocks-laps column-header.button:last-child,
.clocks-laps column-header .button:last-child {
    border-image: none;
    border-style: solid;
    border-width: 0;
    border-radius: 0;
    box-shadow: none;
    background-color:shade(@theme_bg_color, 0.975);
}

.clocks-laps column-header.button:backdrop,
.clocks-laps column-header .button:backdrop {
    background-color: @theme_bg_color;
}
